==> gnuradio-3.1.2.tar.gz: gnuradio-3.1.2/gr-atsc/src/lib/atsc_depad.h <==
/* -*- c++ -*- */
/*
 * Copyright 2006 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */
#ifndef INCLUDED_ATSC_DEPAD_H
#define INCLUDED_ATSC_DEPAD_H

#include <gr_sync_interpolator.h>

class atsc_depad;
typedef boost::shared_ptr<atsc_depad> atsc_depad_sptr;

atsc_depad_sptr atsc_make_depad();

/*!
 * \brief depad mpeg ts packets from 256 byte atsc_mpeg_packet
 * to 188 byte char
 * \ingroup atsc
 *
 * input: atsc_mpeg_packet; output: unsigned char
 */
class atsc_depad : public gr_sync_interpolator
{
  friend atsc_depad_sptr atsc_make_depad();

  atsc_depad();

public:
  void forecast (int noutput_items, gr_vector_int &ninput_items_required);
  int work (int noutput_items,
	    gr_vector_const_void_star &input_items,
	    gr_vector_void_star &output_items);

  void reset() { /* nop */ }
};


#endif /* INCLUDED_ATSC_DEPAD_H */

==> gnuradio_3.5.3.2.orig.tar.gz: gnuradio-3.5.3.2/gr-atsc/src/lib/atsc_depad.h <==
/* -*- c++ -*- */
/*
 * Copyright 2006 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */
#ifndef INCLUDED_ATSC_DEPAD_H
#define INCLUDED_ATSC_DEPAD_H

#include <atsc_api.h>
#include <gr_sync_interpolator.h>

class atsc_depad;
typedef boost::shared_ptr<atsc_depad> atsc_depad_sptr;

ATSC_API atsc_depad_sptr atsc_make_depad();

/*!
 * \brief depad mpeg ts packets from 256 byte atsc_mpeg_packet to 188 byte char
 * \ingroup atsc
 *
 * input: atsc_mpeg_packet; output: unsigned char
 */
class ATSC_API atsc_depad : public gr_sync_interpolator
{
  friend ATSC_API atsc_depad_sptr atsc_make_depad();

  atsc_depad();

public:
  int work (int noutput_items,
	    gr_vector_const_void_star &input_items,
	    gr_vector_void_star &output_items);

  void reset() { /* nop */ }
};


#endif /* INCLUDED_ATSC_DEPAD_H */
